@@ -147,8 +147,6 @@ def mongodb(request, mongo_proc):
         config.mongo.port
     )
 
-    mongodb = mongo_conn[config.mongo.db]
-
     def drop():
         for db in mongo_conn.database_names():
             for collection_name in mongo_conn[db].collection_names():
@@ -157,7 +155,7 @@ def mongodb(request, mongo_proc):
 
     request.addfinalizer(drop)
     drop()
-    return mongodb
+    return mongo_conn
 
 
 def get_rabbit_env(name):
@@ -244,8 +242,8 @@ def mysql_proc(request):
     mysql_executor = TCPCoordinatedExecutor(
         '''
             {mysql_server} --datadir={datadir} --pid-file={pidfile}
-            --port={port} --socket={socket}
-        '''.format(
+            --port={port} --socket={socket}'''
+        .format(
             mysql_server=config.mysql.mysql_server,
             datadir=config.mysql.datadir,
             pidfile=config.mysql.pidfile,
